Functions
- build_
input_ schema - Converts a list of
ApiParams and an optional request body schema into a JSON Schema suitable for MCP toolinput_schema. - inject_
description - Adds a “description” key to a JSON Schema object.
ApiParams and an optional request body schema into a
JSON Schema suitable for MCP tool input_schema.